@@ -1,8 +1,8 @@
 # --
 # Kernel/System/SysConfig.pm - all system config tool functions
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: SysConfig.pm,v 1.28 2011/01/27 10:47:53 mb Exp $
+# $Id: SysConfig.pm,v 1.34 2012/03/01 18:04:44 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -21,7 +21,7 @@ use Kernel::Config;
 use Kernel::Language;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.28 $) [1];
+$VERSION = qw($Revision: 1.34 $) [1];
 
 =head1 NAME
 
@@ -107,13 +107,8 @@ sub new {
     $Self->{Home} = $Self->{ConfigObject}->Get('Home');
 
     # set utf8 if used
-    if ( $Self->{ConfigObject}->Get('DefaultCharset') =~ /^utf(-8|8)$/i ) {
-        $Self->{utf8}     = 1;
-        $Self->{FileMode} = ':utf8';
-    }
-    else {
-        $Self->{FileMode} = '';
-    }
+    $Self->{utf8}     = 1;
+    $Self->{FileMode} = ':utf8';
 
     # create xml object
     $Self->{XMLObject} = Kernel::System::XML->new(%Param);
@@ -184,27 +179,22 @@ sub WriteDefault {
 
     # write default config file
     my $Out;
-    if ( !open( $Out, ">$Self->{FileMode}", "$Self->{Home}/Kernel/Config/Files/ZZZAAuto.pm" ) ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => "Can't write $Self->{Home}/Kernel/Config/Files/ZZZAAuto.pm: $!!",
-        );
-        return;
-    }
-
-    print $Out "# OTRS config file (automatically generated)\n";
-    print $Out "# VERSION:1.1\n";
-    print $Out "package Kernel::Config::Files::ZZZAAuto;\n";
+    $Out .= "# OTRS config file (automatically generated)\n";
+    $Out .= "# VERSION:1.1\n";
+    $Out .= "package Kernel::Config::Files::ZZZAAuto;\n";
     if ( $Self->{utf8} ) {
-        print $Out "use utf8;\n";
+        $Out .= "use utf8;\n";
     }
-    print $Out "sub Load {\n";
-    print $Out "    my (\$File, \$Self) = \@_;\n";
-    print $Out $File;
-    print $Out "}\n";
-    print $Out "1;\n";
-    close($Out);
-    return 1;
+    $Out .= "sub Load {\n";
+    $Out .= "    my (\$File, \$Self) = \@_;\n";
+    $Out .= $File;
+    $Out .= "}\n";
+    $Out .= "1;\n";
+
+    return $Self->_FileWriteAtomic(
+        Filename => "$Self->{Home}/Kernel/Config/Files/ZZZAAuto.pm",
+        Content  => \$Out,
+    );
 }
 
 =item Download()
@@ -400,28 +390,22 @@ sub CreateConfig {
 
     # write new config file
     my $Out;
-    if ( !open( $Out, ">$Self->{FileMode}", "$Home/Kernel/Config/Files/ZZZAuto.pm" ) ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => "Can't write $Home/Kernel/Config/Files/ZZZAuto.pm!",
-        );
-        return;
-    }
-
-    print $Out "# OTRS config file (automatically generated)\n";
-    print $Out "# VERSION:1.1\n";
-    print $Out "package Kernel::Config::Files::ZZZAuto;\n";
+    $Out .= "# OTRS config file (automatically generated)\n";
+    $Out .= "# VERSION:1.1\n";
+    $Out .= "package Kernel::Config::Files::ZZZAuto;\n";
     if ( $Self->{utf8} ) {
-        print $Out "use utf8;\n";
+        $Out .= "use utf8;\n";
     }
-    print $Out "sub Load {\n";
-    print $Out "    my (\$File, \$Self) = \@_;\n";
-    print $Out $File;
-    print $Out "}\n";
-    print $Out "1;\n";
-    close($Out);
+    $Out .= "sub Load {\n";
+    $Out .= "    my (\$File, \$Self) = \@_;\n";
+    $Out .= $File;
+    $Out .= "}\n";
+    $Out .= "1;\n";
 
-    return 1;
+    return $Self->_FileWriteAtomic(
+        Filename => "$Self->{Home}/Kernel/Config/Files/ZZZAuto.pm",
+        Content  => \$Out,
+    );
 }
 
 =item ConfigItemUpdate()
@@ -540,20 +524,15 @@ sub ConfigItemUpdate {
     }
     close($In);
 
-    # write it to file
-    if ( !open( $Out, ">$Self->{FileMode}", "$Home/Kernel/Config/Files/ZZZAuto.pm" ) ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => "Can't write $Home/Kernel/Config/Files/ZZZAuto.pm: $!",
-        );
-        return;
+    my $Content;
+    for my $Line ( reverse @FileNew ) {
+        $Content .= $Line;
     }
 
-    for my $Line ( reverse @FileNew ) {
-        print $Out $Line;
-    }
-    close($Out);
-    return 1;
+    return $Self->_FileWriteAtomic(
+        Filename => "$Self->{Home}/Kernel/Config/Files/ZZZAuto.pm",
+        Content  => \$Content,
+    );
 }
 
 =item ConfigItemGet()
@@ -1452,6 +1431,9 @@ sub ConfigItemValidate {
         # if the valid param is given, use it, otherwise take valid setting from config item
         my $Valid = defined $Param{Valid} ? $Param{Valid} : $ConfigItem{Valid};
 
+        # skip validation of invalid items
+        return 1 if !$Valid;
+
         # update the config item with the new value
         my $UpdateSuccess = $Self->ConfigItemUpdate(
             Valid        => $Valid,
@@ -1619,19 +1601,16 @@ sub _Init {
                     my $Dump = $Self->{MainObject}->Dump( \@XMLHash, 'ascii' );
                     $Dump =~ s/\$VAR1/\$XMLHashRef/;
                     my $Out;
-                    if ( open( $Out, ">$Self->{FileMode}", $FileCache ) ) {
-                        if ( $Self->{utf8} ) {
-                            print $Out "use utf8;\n";
-                        }
-                        print $Out $Dump . "\n1;";
-                        close($Out);
-                    }
-                    else {
-                        $Self->{LogObject}->Log(
-                            Priority => 'error',
-                            Message  => "Can't write cache file $FileCache: $!",
-                        );
+
+                    if ( $Self->{utf8} ) {
+                        $Out .= "use utf8;\n";
                     }
+                    $Out .= $Dump . "\n1;";
+
+                    $Self->_FileWriteAtomic(
+                        Filename => $FileCache,
+                        Content  => \$Out,
+                    );
                 }
             }
         }
@@ -1784,8 +1763,12 @@ sub _DataDiff {
         # compare %A with %B and remove it if checked
         for my $Key ( keys %A ) {
 
-            # do nothing, it's ok
-            next if !defined $A{$Key} && !defined $B{$Key};
+            # Check if both are undefined
+            if ( !defined $A{$Key} && !defined $B{$Key} ) {
+                delete $A{$Key};
+                delete $B{$Key};
+                next;
+            }
 
             # return diff, because its different
             return 1 if !defined $A{$Key} || !defined $B{$Key};
@@ -1837,6 +1820,54 @@ sub DESTROY {
     return 1;
 }
 
+=item _FileWriteAtomic()
+
+writes a file in an atomic operation. This is achieved by creating
+a temporary file, filling and renaming it. This avoids inconsistent states
+when the file is updated.
+
+    my $Success = $SysConfigObject->_FileWriteAtomic(
+        Filename => "$Self->{Home}/Kernel/Config/Files/ZZZAAuto.pm",
+        Content  => \$NewContent,
+    );
+
+=cut
+
+sub _FileWriteAtomic {
+    my ( $Self, %Param ) = @_;
+
+    for (qw(Filename Content)) {
+        if ( !defined $Param{$_} ) {
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            return;
+        }
+    }
+
+    my $TempFilename = $Param{Filename} . '.' . $$;
+    my $FH;
+
+    if ( !open( $FH, ">$Self->{FileMode}", $TempFilename ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Can't open file $TempFilename!",
+        );
+        return;
+    }
+
+    print $FH ${ $Param{Content} };
+    close $FH;
+
+    if ( !rename $TempFilename, $Param{Filename} ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Could not rename $TempFilename to $Param{Filename}!"
+        );
+        return;
+    }
+
+    return 1;
+}
+
 sub _ConfigItemTranslatableStrings {
     my ( $Self, %Param ) = @_;
 
@@ -2252,6 +2283,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.28 $ $Date: 2011/01/27 10:47:53 $
+$Revision: 1.34 $ $Date: 2012/03/01 18:04:44 $
 
 =cut
