@@ -3,7 +3,7 @@
 # bin/otrs.CheckModules.pl - to check needed cpan framework modules
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: otrs.CheckModules.pl,v 1.35 2012/03/17 01:18:54 mh Exp $
+# $Id: otrs.CheckModules.pl,v 1.36.2.1 2012/12/11 16:04:14 mg Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -38,6 +38,11 @@ my @NeededModules = (
         Module   => 'Crypt::PasswdMD5',
         Required => 1,
     },
+    {
+        Module   => 'Crypt::SSLeay',
+        Required => 0,
+        Comment  => 'Required for Generic Interface SOAP SSL connections.',
+    },
     {
         Module   => 'CSS::Minifier',
         Required => 1,
@@ -293,6 +298,11 @@ my @NeededModules = (
         Required => 0,
         Comment  => 'Required for directory authentication.',
     },
+    {
+        Module   => 'Net::SSL',
+        Required => 0,
+        Comment  => 'Required for Generic Interface SOAP SSL connections.',
+    },
     {
         Module       => 'PDF::API2',
         Version      => '0.57',
@@ -379,6 +389,11 @@ my @NeededModules = (
             },
         ],
     },
+    {
+        Module   => 'Time::HiRes',
+        Required => 1,
+        Comment  => 'Required for high resolution timestamps.',
+    },
     {
         Module   => 'XML::Parser',
         Required => 0,
